Video Analysis
---------------

*video_plot()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.video.video_plot

*video_face()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.video.video_face

*video_skin()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.video.video_skin

*video_ppg()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.video.video_ppg

